# 版本更新需要保证代码兼容(原使用代码不出问题)
__version__ = "0.0.11"

from . import time_utils,json_utils,logging_utils
from . import os_utils,special_utils
# from . import sklearn_utils
from . import trie_tree

# 常用的一些函数，尽量保持不轻易变化
from .time_utils import get_time, get_today, backto_Ndays, backto_Ntoday
from .json_utils import read_json_file, save_json_file, read_txt_file, save_txt_file, trans2json
from .logging_utils import create_log_file, FileLogger, write_logger, update_logger
from .special_utils import remove_emoji,remove_quote,trans_singleQM2doubleQM,sort_dict
from .judge_utils import judge_not, judge_negative_entity, judge_suffix,split_name_and_suffix, judge_suffix_type
from .re_utils import clean_illegal_character
from .math_utils import radian2angle, angle2radian

from .constants import SUFFIX_TYPE_DICT, EN_PUNCTUATION,CN_PUNCTUATION,ALL_PUNCTUATION
#  from .conn_pg import MysqlConnection
